@@ -6,6 +6,7 @@ import logging
 import subprocess
 from pathlib import Path
 from typing import TypedDict, Optional, Dict, List, Any
+from rich.console import Console
 from machineconfig.utils.scheduler import Scheduler
 from machineconfig.cluster.sessions_managers.wt_local import WTLayoutGenerator
 from machineconfig.utils.schemas.layouts.layout_types import LayoutConfig
@@ -21,6 +22,7 @@ class WTSessionReport(TypedDict):
 
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__name__)
+console = Console()
 
 TMP_SERIALIZATION_DIR = Path.home().joinpath("tmp_results", "session_manager", "wt", "local_manager")
 
@@ -220,11 +222,11 @@ class WTLocalManager:
                 cmd_text = cmd_status.get("command", "Unknown")[:50]
                 if len(cmd_status.get("command", "")) > 50:
                     cmd_text += "..."
-                print(f"     {status_icon} {tab_name}: {cmd_text}")
+                console.print(f"     {status_icon} {tab_name}: {cmd_text}")
 
                 if cmd_status.get("processes"):
                     for proc in cmd_status["processes"][:2]:  # Show first 2 processes
-                        print(f"        └─ PID {proc['pid']}: {proc['name']}")
+                        console.print(f"        [dim]└─[/dim] PID {proc['pid']}: {proc['name']}")
             print()
 
         print("=" * 80)
