@@ -98,7 +98,7 @@ def print_code(code: str, lexer: str, desc: str, subtitle: str = ""):
     console.print(Panel(Syntax(code=code, lexer=lexer), title=f"📄 {desc}", subtitle=subtitle), style="bold red")
 
 
-def run_script(program: str):
+def run_shell_script(program: str, display_script: bool = True):
     import tempfile
     if platform.system() == "Windows":
         suffix = ".ps1"
@@ -110,16 +110,19 @@ def run_script(program: str):
         temp_file.write(program)
         temp_script_path = PathExtended(temp_file.name)
     console = Console()
-    # console.print(f"📝 [blue]Temporary script written to:[/blue] [green]{temp_script_path}[/green]")
-    from rich.syntax import Syntax
-    console.print(Panel(Syntax(code=program, lexer=lexer), title=f"📄script @ {temp_script_path}", subtitle="shell code"), style="bold red")
+    if display_script:
+        from rich.syntax import Syntax
+        console.print(Panel(Syntax(code=program, lexer=lexer), title=f"📄 shell script @ {temp_script_path}", subtitle="shell script being executed"), style="bold red")
+
     if platform.system() == "Windows":
         import subprocess
         subprocess.run(f'powershell -ExecutionPolicy Bypass -File "{temp_script_path}"', check=True, shell=True)
     elif platform.system() == "Linux" or platform.system() == "Darwin":
         import subprocess
         subprocess.run(f"bash {str(temp_script_path)}", check=True, shell=True)
+
     temp_script_path.unlink(missing_ok=True)
+
 # def run_command(command: str, description: str) -> bool:
 #     """Execute a shell command and return success status."""
 #     console.print(f"\n🔧 {description}", style="bold cyan")
